---
layout: model
title: Detect Problems, Tests and Treatments (ner_crf)
author: John Snow Labs
name: ner_crf
class: NerCrfModel
language: en
nav_key: models
repository: clinical/models
date: 2020-01-28
task: Named Entity Recognition
edition: Healthcare NLP 2.4.0
spark_version: 2.4
tags: [ner]
supported: true
annotator: NerCrfModel
article_header:
   type: cover
use_language_switcher: "Python-Scala-Java"
---

{:.h2_title}
## Description
Named Entity recognition annotator allows for a generic model to be trained by CRF model
Clinical NER (Large) is a Named Entity Recognition model that annotates text to find references to clinical events. The entities it annotates are Problem, Treatment, and Test. Clinical NER is trained with the 'embeddings_clinical' word embeddings model, so be sure to use the same embeddings in the pipeline.

## Predicted Entities
`Problem`, `Test`, `Treatment`

{:.btn-box}
<button class="button button-orange" disabled>Live Demo</button>
<button class="button button-orange" disabled>Open in Colab</button>
[Download](https://s3.amazonaws.com/auxdata.johnsnowlabs.com/clinical/models/ner_crf_en_2.4.0_2.4_1580237286004.zip){:.button.button-orange.button-orange-trans.arr.button-icon.hidden}
[Copy S3 URI](s3://auxdata.johnsnowlabs.com/clinical/models/ner_crf_en_2.4.0_2.4_1580237286004.zip){:.button.button-orange.button-orange-trans.button-icon.button-copy-s3}
{:.h2_title}
## How to use 
<div class="tabs-box" markdown="1">

{% include programmingLanguageSelectScalaPython.html %}

```python
model = NerCrfModel.pretrained("ner_crf","en","clinical/models")\
	.setInputCols("sentence","token","pos","word_embeddings")\
	.setOutputCol("ner")
```

```scala
val model = NerCrfModel.pretrained("ner_crf","en","clinical/models")
	.setInputCols("sentence","token","pos","word_embeddings")
	.setOutputCol("ner")
```
</div>



{:.model-param}
## Model Information

{:.table-model}
|---------------|---------------------------------------|
| Name:          | ner_crf                               |
| Type:   | NerCrfModel                           |
| Compatibility: | Spark NLP 2.4.0+                                 |
| License:       | Licensed                              |
| Edition:       | Official                            |
|Input labels:        | [sentence, token, pos, word_embeddings] |
|Output labels:       | [ner]                                   |
| Language:      | en                                    |
| Dependencies: | embeddings_clinical                   |

{:.h2_title}
## Data Source
Trained with augmented version of i2b2 dataset with`clinical_embeddings`
FILLUP